[Scummvm-cvs-logs] CVS: scummvm/scumm scummvm.cpp,2.278,2.279

Max Horn fingolfin at users.sourceforge.net
Sun Jul 13 13:28:27 CEST 2003


Update of /cvsroot/scummvm/scummvm/scumm
In directory sc8-pr-cvs1:/tmp/cvs-serv20690

Modified Files:
	scummvm.cpp 
Log Message:
workaround for bug #770093 (Zak256 Crash inside of Sphinx)

Index: scummvm.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/scumm/scummvm.cpp,v
retrieving revision 2.278
retrieving revision 2.279
diff -u -d -r2.278 -r2.279
--- scummvm.cpp	13 Jul 2003 15:13:43 -0000	2.278
+++ scummvm.cpp	13 Jul 2003 20:27:28 -0000	2.279
@@ -1283,9 +1283,17 @@
 				error("Object %d stopped with active cutscene/override in exit", ss->number);
 			_currentScript = 0xFF;
 		} else if (ss->where == WIO_LOCAL) {
-			// HACK to make Indy3 Demo work
-			if (ss->cutsceneOverride != 0 && !(_gameId == GID_INDY3 && _roomResource == 3))
-				error("Script %d stopped with active cutscene/override in exit", ss->number);
+			if (ss->cutsceneOverride != 0) {
+				if (_gameId == GID_ZAK256 && _roomResource == 15 && ss->number == 202) {
+					// HACK to make Zak256 work (see bug #770093)
+					warning("Script %d stopped with active cutscene/override in exit", ss->number);
+				} else if (_gameId == GID_INDY3 && _roomResource == 3) {
+					// HACK to make Indy3 Demo work
+					warning("Script %d stopped with active cutscene/override in exit", ss->number);
+				} else {
+					error("Script %d stopped with active cutscene/override in exit", ss->number);
+				}
+			}
 			_currentScript = 0xFF;
 		}
 	}





More information about the Scummvm-git-logs mailing list